package exceptionmanager.handler;

import java.lang.Thread.UncaughtExceptionHandler;
import java.util.HashMap;
import java.util.Map;

import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;

import exceptionmanager.reporter.DefaultExceptionReporter;
import exceptionmanager.reporter.IExceptionReporter;

public class AIBenchExceptionManager implements UncaughtExceptionHandler {
	
	protected static AIBenchExceptionManager	_instance;
	private Map<Class<?>, IHandlerException>	mapException;
	private IExceptionReporter					reporter;
	private boolean								active	= true;
	
	synchronized static public AIBenchExceptionManager getInstance() {
		if (_instance == null) 
			_instance = new AIBenchExceptionManager();
		
		return _instance;
	}
	
	private AIBenchExceptionManager() {
		mapException = new HashMap<Class<?>, IHandlerException>();
	}
	
	public void setReporter(IExceptionReporter reporter) {
		this.reporter = reporter;
	}
	
	public void setActive(boolean active) {
		this.active = active;
	}
	
	public void addHandler(AbstractHandlerException absHandExc) {
		
		Map<Class<?>, String> exceptions = absHandExc.getExceptionsMap();
		
		for (Class<?> e : exceptions.keySet()) {
			if (mapException.containsKey(e)) throw new DuplicatedException(e);
			mapException.put(e, absHandExc);
		}
	}
	
	private String treatThrowable(Throwable e) {
		
		String msg = e.toString() + ": " + e.getMessage();
		
		if (mapException.containsKey(e.getClass())) {
			if (mapException.get(e.getClass()).getExceptionMessage(e) != null) 
				msg = mapException.get(e.getClass()).getExceptionMessage(e);			
		} else {
			getReporter().reportBug(e);
			msg = null;
		}
		
		return msg;
	}
	
	public void handleException(Throwable e) {
		
		if (active) {
			String msg = treatThrowable(e);
			if (msg != null) 
				displayError(msg);
		}
	
		e.printStackTrace();
	}
	
	public IExceptionReporter getReporter() {
		if (reporter == null) 
			reporter = new DefaultExceptionReporter();		
		return reporter;
	}
	
	@Override
	public void uncaughtException(Thread t, Throwable e) {
		handleException(e);
	}
	
	public static void displayError(final String message){
		SwingUtilities.invokeLater(new Runnable(){
			public void run(){
				JOptionPane.showMessageDialog(null, message, "Error", JOptionPane.ERROR_MESSAGE);
			}
		});
	}
}
